@@ -361,7 +361,8 @@ Functions:
         LENGTH | LEN                Returns length of string value
         LOWER | LOWERCASE | LCASE   Returns lowercase value
         UPPER | UPPERCASE | UCASE   Returns uppercase value
-        BASE64                      Returns Base64 digest of a value
+        TO_BASE64 | BASE64          Returns Base64 digest of a value
+        FROM_BASE64                 Returns decoded value from a Base64 digest
         SUBSTRING | SUBSTR          Returns part of the string value
         REPLACE                     Returns string with substring replaced with another one
         TRIM                        Returns string with whitespaces at the beginning and the end stripped
